pub struct Migrate { /* private fields */ }Expand description
Transaction that migrates a trail to the latest package version supported by this crate.
This requires the Migrate permission on the supplied capability and succeeds only when the on-chain
package version is strictly less than the current supported version. Otherwise the Move package aborts
with EPackageVersionMismatch.
On success an AuditTrailMigrated event is emitted.
Implementations